@@ -2,10 +2,9 @@ package PICA::Parser::Binary;
 use strict;
 use warnings;
 
-our $VERSION = '0.37';
+our $VERSION = '1.00';
 
 use charnames qw(:full);
-use Carp qw(croak);
 
 use parent 'PICA::Parser::Plus';
 
@@ -14,16 +13,15 @@ sub END_OF_FIELD       { "\N{INFORMATION SEPARATOR TWO}" }
 sub END_OF_RECORD      { "\N{INFORMATION SEPARATOR THREE}" }
 
 1;
-
 __END__
 
 =head1 NAME
 
 PICA::Parser::Binary - Binary PICA+ format parser
 
-=head2 DESCRIPTION
+=head1 DESCRIPTION
 
-See L<PICA::Parser::Base> for synopsis and details.
+See L<PICA::Parser::Base> for synopsis and configuration.
 
 The counterpart of this module is L<PICA::Writer::Binary>.
 
